@@ -3,7 +3,7 @@ package Net::FTP::Find::Mixin;
 use strict;
 use warnings;
 
-our $VERSION = '0.031';
+our $VERSION = '0.032';
 
 use Carp;
 use File::Spec;
@@ -321,8 +321,8 @@ sub parse_entries {
 			$l =~ s/
 				(\s\d+\s+)
 				(\d+)\S*
-				(?=\s+\d+\s+\d{2}:\d{2})
-			/$1 . $month_name_list[$2]/ex;
+				(?=\s+\d+\s+(\d{2}:\d{2}|\d{4}))
+			/$1 . $month_name_list[$2-1]/ex;
 			my ($data) = File::Listing::parse_dir($l, $tz, $fstype, $error);
 			$data ? +{ line => $_, data => $data } : ()
 		} @$dir;
